@@ -2,21 +2,30 @@
 
 import struct
 
-from pyplumio import structures, util
+from pyplumio import util
 from pyplumio.constants import (
     EDITABLE_PARAMS,
     MODES,
     WLAN_ENCRYPTION,
     WLAN_ENCRYPTION_NONE,
 )
-from pyplumio.frame import Frame
+from pyplumio.frame import Response
+from pyplumio.structures import (
+    alarms,
+    frame_versions,
+    lambda_,
+    mixers,
+    output_flags,
+    outputs,
+    temperatures,
+    thermostats,
+    uid,
+    var_string,
+    versions,
+)
 from pyplumio.version import __version__
 
 
-class Response(Frame):
-    """Base class for all response frames."""
-
-
 class ProgramVersion(Response):
     """Contains information about device software and hardware version."""
 
@@ -142,7 +151,7 @@ class DeviceAvailable(Response):
         self._data["wlan"]["quality"] = int(message[offset + 2])
         self._data["wlan"]["status"] = bool(message[offset + 3])
         offset += 8
-        self._data["wlan"]["ssid"] = structures.VarString.from_bytes(message, offset)
+        self._data["wlan"]["ssid"] = var_string.from_bytes(message, offset)
 
 
 class CurrentData(Response):
@@ -158,25 +167,21 @@ class CurrentData(Response):
         """
         offset = 0
         self._data = {}
-        self._data["frame_versions"], offset = structures.FrameVersions.from_bytes(
+        self._data["frame_versions"], offset = frame_versions.from_bytes(
             message, offset
         )
         self._data["mode"] = message[offset]
         self._data["modeString"] = MODES[self._data["mode"]]
         offset += 1
-        self._data["outputs"], offset = structures.Outputs.from_bytes(message, offset)
-        self._data["output_flags"], offset = structures.OutputFlags.from_bytes(
-            message, offset
-        )
-        self._data["temperatures"], offset = structures.Temperatures.from_bytes(
-            message, offset
-        )
+        self._data["outputs"], offset = outputs.from_bytes(message, offset)
+        self._data["output_flags"], offset = output_flags.from_bytes(message, offset)
+        self._data["temperatures"], offset = temperatures.from_bytes(message, offset)
         self._data["tempCOSet"] = message[offset]
         self._data["statusCO"] = message[offset + 1]
         self._data["tempCWUSet"] = message[offset + 2]
         self._data["statusCWU"] = message[offset + 3]
         offset += 4
-        self._data["alarms"], offset = structures.Alarms.from_bytes(message, offset)
+        self._data["alarms"], offset = alarms.from_bytes(message, offset)
         self._data["fuelLevel"] = message[offset]
         self._data["transmission"] = message[offset + 1]
         self._data["fanPower"] = util.unpack_float(message[offset + 2 : offset + 6])[0]
@@ -189,12 +194,10 @@ class CurrentData(Response):
         )[0]
         self._data["thermostat"] = message[offset + 15]
         offset += 16
-        self._data["versions"], offset = structures.Versions.from_bytes(message, offset)
-        self._data["lambda"], offset = structures.Lambda.from_bytes(message, offset)
-        self._data["thermostats"], offset = structures.Thermostats.from_bytes(
-            message, offset
-        )
-        self._data["mixers"], offset = structures.Mixers.from_bytes(message, offset)
+        self._data["versions"], offset = versions.from_bytes(message, offset)
+        self._data["lambda"], offset = lambda_.from_bytes(message, offset)
+        self._data["thermostats"], offset = thermostats.from_bytes(message, offset)
+        self._data["mixers"], offset = mixers.from_bytes(message, offset)
 
 
 class UID(Response):
@@ -214,12 +217,12 @@ class UID(Response):
         offset += 1
         self._data["reg_prod"] = util.unpack_ushort(message[offset : offset + 2])
         offset += 2
-        self._data["UID"], offset = structures.UID.from_bytes(message, offset)
+        self._data["UID"], offset = uid.from_bytes(message, offset)
         self._data["reg_logo"] = util.unpack_ushort(message[offset : offset + 2])
         offset += 2
         self._data["reg_img"] = util.unpack_ushort(message[offset : offset + 2])
         offset += 2
-        self._data["reg_name"] = structures.VarString.from_bytes(message, offset)
+        self._data["reg_name"] = var_string.from_bytes(message, offset)
 
 
 class Password(Response):
@@ -278,7 +281,7 @@ class RegData(Response):
             (
                 self._data["frame_versions"],
                 offset,
-            ) = structures.FrameVersions.from_bytes(message, offset)
+            ) = frame_versions.from_bytes(message, offset)
 
 
 class Timezones(Response):
@@ -357,3 +360,18 @@ class DataStructure(Response):
                 param_id = util.unpack_ushort(message[offset + 1 : offset + 3])
                 self._data.append({"id": param_id, "type": param_type})
                 offset += 3
+
+
+class SetParameter(Response):
+    """Contains set parameter response."""
+
+    type_: int = 0xB3
+
+
+class BoilerControl(Response):
+    """Contains boiler control response."""
+
+    type_: int = 0xBB
+
+    def parse_message(self, message: bytearray) -> None:
+        print(message)
