@@ -4,17 +4,18 @@ from __future__ import annotations
 
 from asyncio import StreamReader, StreamWriter
 
-from pyplumio.constants import (
+from . import util
+from .constants import (
     BROADCAST_ADDRESS,
     ECONET_ADDRESS,
     HEADER_SIZE,
     READER_BUFFER_SIZE,
 )
-
-from . import util
-from .exceptions import ChecksumError, FrameTypeError, LengthError
+from .devices import Parameter
+from .exceptions import ChecksumError, LengthError
 from .factory import FrameFactory
 from .frame import Frame
+from .frames.requests import Parameters
 
 
 class FrameWriter:
@@ -36,19 +37,32 @@ class FrameWriter:
         """Gets write queue length."""
         return len(self._queue)
 
-    def queue(self, frame: Frame) -> None:
+    def queue(self, *frames: list[Frame]) -> None:
         """Adds frame to write queue.
 
         Keyword arguments:
         frame -- Frame instance to add
         """
-        if isinstance(frame, Frame):
-            self._queue.append(frame)
+        for frame in frames:
+            if isinstance(frame, Frame):
+                self._queue.append(frame)
 
     def queue_is_empty(self) -> bool:
         """Checks if write queue is empty."""
         return len(self._queue) == 0
 
+    def collect(self, parameters: dict[Parameter]) -> None:
+        """Collects changed parameters and adds them to write queue.
+
+        Keyword arguments:
+        parameters -- list of device parameters
+        """
+        for parameter in parameters:
+            self.queue(parameter.request)
+
+        if parameters:
+            self.queue(Parameters())
+
     async def process_queue(self) -> None:
         """Processes top-most write request from the stack."""
         if self._queue:
@@ -64,9 +78,10 @@ class FrameWriter:
         self.writer.write(frame.to_bytes())
         await self.writer.drain()
 
-    def close(self) -> None:
+    async def close(self) -> None:
         """Closes StreamWriter."""
         self.writer.close()
+        await self.writer.wait_closed()
 
 
 class FrameReader:
@@ -109,14 +124,11 @@ class FrameReader:
                 if payload[-2] != util.crc(header + payload[:-2]):
                     raise ChecksumError()
 
-                try:
-                    return FrameFactory().get_frame(
-                        type_=payload[0],
-                        recipient=recipient,
-                        message=payload[1:-2],
-                        sender=sender,
-                        sender_type=sender_type,
-                        econet_version=econet_version,
-                    )
-                except FrameTypeError:
-                    pass
+                return FrameFactory().get_frame(
+                    type_=payload[0],
+                    recipient=recipient,
+                    message=payload[1:-2],
+                    sender=sender,
+                    sender_type=sender_type,
+                    econet_version=econet_version,
+                )
